@@ -199,8 +199,11 @@ class UdpSession(object):
             # format: "[packetType], [ctx], [datas: xxxx xxxx xxxx]"
             datas = [str(param_id), request]
             if param_id == ParamDef.MODULE_DEPENDENCY:
-                import pip
-                data = ', '.join(map(str, list(pip.get_installed_distributions())))
+                try:
+                    from pip._internal.utils.misc import get_installed_distributions
+                except ImportError:
+                    from pip import get_installed_distributions
+                data = ', '.join(map(str, list(get_installed_distributions())))
                 datas.append(data)
             elif param_id == ParamDef.GET_ACTIVE_TRANSACTION_DETAIL:
                 data = extra.replace(' ', ', ')
